// ==============================================================
// ORBITER vessel module: Mercury Redstone
// ==============================================================

#include "orbitersdk.h"
#include <stdio.h>
#include <fstream.h>

//const double PI  = 3.14159265359;
//const double RAD = PI/180.0;

char sat_mesh_name[256];


void SetStage (VESSEL *vessel)
{
	vessel->ClearMeshes();
	vessel->AddMesh (sat_mesh_name);
}

// ==============================================================
// API interface
// ==============================================================

// Initialisation
DLLCLBK VESSEL *ovcInit (OBJHANDLE hvessel, int flightmodel)
{
	strcpy(sat_mesh_name,"sts_sat");
	return new VESSEL (hvessel, flightmodel);
}

// Cleanup
DLLCLBK void ovcExit (VESSEL *vessel)
{
	if (vessel) delete vessel;
}

// Keyboard interface handler
DLLCLBK int ovcConsumeKey (VESSEL *vessel, const char *keystate)
{
	OBJHANDLE hvessel;
	if (KEYMOD_SHIFT (keystate)) 
	{
		return 0; // shift combinations are reserved
	}
	else if (KEYMOD_CONTROL (keystate)) 
	{
		// insert ctrl key combinations here
	}
	else 
	{ // unmodified keys
		if (KEYDOWN (keystate, OAPI_KEY_J)) { 
			if (oapiAcceptDelayedKey (OAPI_KEY_J, 1.0))
			{
				char name[256];
				char vname[256];
				UINT i;
				strcpy (vname,vessel->GetName());
				for (i=0;i<strlen(vname)+1;i++)
					name[i]=0;

				for (i=0;i<strlen(vname)-4;i++)
					name[i]=vname[i];
				hvessel=oapiGetVesselByName(name);
				if (hvessel != 0)
					oapiSetFocusObject(hvessel);
			};
			return 1;
		}
	}
	return 0;
}

// Set the capabilities of the vessel class
DLLCLBK void ovcSetClassCaps (VESSEL *vessel, FILEHANDLE cfg)
{
    char *line;
	while (oapiReadScenario_nextline (cfg, line)) {
		if (!strnicmp (line, "SAT_MESH", 8)) {
			sscanf (line+8, "%s", sat_mesh_name);
        } 
    }
	SetStage(vessel);
}


DLLCLBK void ovcTimestep (VESSEL *vessel, double simt)
{

}


DLLCLBK void ovcSetState (VESSEL *vessel, const VESSELSTATUS *status)
{
	vessel->DefSetState (status);	        // default initialisation
}